<?php

namespace App\Http\Controllers;

use App\Models\Category;
use Illuminate\Http\Request;
use App\Models\Game;
use Illuminate\Support\Facades\Log;

class APIController extends Controller
{
    public function index()
    {
        return Game::where('status', 1)->orderBy('id', 'desc')->get();
    }

    // Get a single game by ID
    public function show($id)
    {
        return Game::findOrFail($id);
    }

    // Get featured games
    public function featured()
    {
        return Game::where('featured', true)->where('status', 1)->limit(5)->get();
    }

    // Search games by title or description
    public function search(Request $request)
    {
        $query = $request->input('query');

        $games =Game::where(function ($q) use ($query) {
            $q->where('name', 'like', '%' . $query . '%')
                ->orWhere('description', 'like', '%' . $query . '%')
                ->orWhere('tags', 'like', '%' . $query . '%')
                ->orWhereHas('category', function ($q) use ($query) {
                    $q->where('name', 'like', '%' . $query . '%');
                });
        })
        ->where('status', 1)
        ->orderBy('id', 'DESC')
        ->get();


    }

    public function categories() {
        return Category::where('is_active', 1)->orderBy('name', 'asc')->get();
    }

    public function categoryGames($id) {
        return Game::where('category_id', $id)->where('status', 1)->orderBy('id', 'asc')->get();
    }
}
