<?php

namespace App\Http\Controllers;

use App\Models\DynamicPopups;
use Illuminate\Http\Request;

class DynamicPopupsController extends Controller
{
    public function DynamicPopups() {
        $dynamicPopups = DynamicPopups::orderBy('id', 'desc')->paginate(10);
        return view('backend.popups.index', compact('dynamicPopups'));
    }

    public function AddPopup() {
        return view('backend.popups.create');
    }

    public function storePopup(Request $request) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $request->validate([
                'title' => 'required|string|max:255',
                'summary' => 'required|string',
            ]);

            // Handle the image upload using public_path
            $imagePath = null;
            if ($request->hasFile('image')) {
                $image = $request->file('image');
                $imageName = time() . '_' . $image->getClientOriginalName();
                $image->move(public_path('images/dynamic-popups'), $imageName);
                $imagePath = $imageName;
            }

            // Create a new dynamic popup entry
            $dynamicPopup = new DynamicPopups();
            $dynamicPopup->title = $request->input('title');
            $dynamicPopup->summary = $request->input('summary');
            $dynamicPopup->image = $imagePath;
            $dynamicPopup->btn_link = $request->input('btn_link');
            $dynamicPopup->btn_text = $request->input('btn_text');
            $dynamicPopup->btn_background_color = $request->input('button_color_text');
            $dynamicPopup->btn_text_color = $request->input('btn_text_color');
            $dynamicPopup->show_subscribe_form = $request->input('show_subscribe_form');
            $dynamicPopup->status = 1;
            $dynamicPopup->save();

            return redirect()->back()->with('success', 'Dynamic popup created successfully!');
        }
    }

    public function EditPopup($id) {
        $dynamicPopup = DynamicPopups::findOrFail($id);
        return view('backend.popups.edit', compact('dynamicPopup'));
    }

    public function UpdatePopup(Request $request) {

        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $dynamicPopup = DynamicPopups::findOrFail($request->id);

            // Handle the image upload using public_path
            $imagePath = $dynamicPopup->image;
            if ($request->hasFile('image')) {
                $image = $request->file('image');
                $imageName = time() . '_' . $image->getClientOriginalName();
                $image->move(public_path('images/dynamic-popups'), $imageName);
                $imagePath = $imageName;
            }

            // Update the dynamic popup entry
            $dynamicPopup->title = $request->input('title');
            $dynamicPopup->summary = $request->input('summary');
            $dynamicPopup->image = $imagePath;
            $dynamicPopup->btn_link = $request->input('btn_link');
            $dynamicPopup->btn_text = $request->input('btn_text');
            $dynamicPopup->btn_background_color = $request->input('button_color_text');
            $dynamicPopup->btn_text_color = $request->input('btn_text_color');
            $dynamicPopup->show_subscribe_form = $request->input('show_subscribe_form');
            $dynamicPopup->status = 1;
            $dynamicPopup->save();

            return redirect()->route('dynamic.popups')->with('success', 'Dynamic popup updated successfully!');
        }
    }

    public function DeletePopup($id) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $dynamicPopup = DynamicPopups::findOrFail($id);
            $dynamicPopup->delete();
            return redirect()->back()->with('success', 'Dynamic popup deleted successfully!');
        }
    }

    public function updateStatus(Request $request) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            // Find the popup by its ID
            $popup = DynamicPopups::find($request->id);

            if ($popup) {
                // Update the status
                $popup->status = $request->status;
                $popup->save();

                return response()->json(['success' => true]);
            }

            return response()->json(['message' => 'Popup not found!'], 404);
        }
    }
}
