<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use App\Events\UserVisited;
use App\Models\BusinessSettings;
use App\Models\Category;
use App\Models\GameReaction;
use App\Models\User;
use App\Models\UserGameHistory;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;

class UserController extends Controller
{

    public function ActiveUsers() {
        $users = User::where('role', 'user')->where('status', 1)->paginate(15);
        return view('backend.users.active', compact('users'));
    }

    public function InactiveUsers() {
        $users = User::where('role', 'user')->where('status', '!=', 1)->paginate(15);
        return view('backend.users.inactive', compact('users'));
    }

    public function trackVisit(Request $request)
    {
        // Get user IP address
        $ip = $request->ip();

        // Fetch geolocation data using ipinfo.io
        $response = Http::get("http://ipinfo.io/{$ip}/json");
        $locationData = $response->json();

        // Extract latitude and longitude
        list($lat, $lng) = explode(',', $locationData['loc']);

        // Broadcast event with location
        event(new UserVisited($lat, $lng));

        return response()->json(['lat' => $lat, 'lng' => $lng]);
    }

    public function UserToggleStatus(Request $request) {

        if (env('DEMO_MODE') == 'on') {
            return response()->json(['error' => "You can't perform this action in Demo Mode."]);
        } else {
            $user = User::findOrFail($request->id);
            $user->status = $request->is_active;
            $user->save();

            return response()->json(['success' => true]);
        }

    }

    public function edit($id){
        $user = User::findOrFail($id);
        return view('backend.users.edit', compact('user'));
    }

    public function update(Request $request){
        $user = User::findOrFail($request->id);
        $user->name = $request->name;
        $user->email = $request->email;
        $user->save();
        return redirect()->back()->with('success', 'User updated successfully');
    }

    public function delete($id){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', "You can't perform this action in Demo Mode.");
        } else {
            $user = User::findOrFail($id);
            $user->delete();
            return redirect()->back()->with('success', 'User deleted successfully');
        }
    }

    public function userHistory()
    {
        // Get the authenticated user's game visit history
        $history = UserGameHistory::with('game')->where('user_id', Auth::user()->id)->orderBy('visited_at', 'desc')->get();
        $settings = BusinessSettings::pluck('value', 'key')->toArray();
        $hivecategories = Category::where('is_active', 1)->get();
        $categories = Category::where('is_active', 1)->get();
        // Return a view displaying the user's history
        return view('frontend.user.history', compact('history', 'settings', 'hivecategories', 'categories'));
    }

    public function userLikedGames()
    {
        // Get the authenticated user's game visit history
        $likedGames = GameReaction::with('game')->where('user_id', Auth::user()->id)->orderBy('created_at', 'desc')->get();
        $settings = BusinessSettings::pluck('value', 'key')->toArray();
        $hivecategories = Category::where('is_active', 1)->get();
        $categories = Category::where('is_active', 1)->get();
        // Return a view displaying the user's history
        return view('frontend.user.liked-games', compact('likedGames', 'settings', 'hivecategories', 'categories'));
    }

    public function UserProfile(){
        $categories = Category::where('is_active', 1)->get();
        $user = User::findOrFail(Auth::user()->id);
        $settings = BusinessSettings::pluck('value', 'key')->toArray();
        return view('frontend.user.profile', compact('user', 'settings', 'categories'));
    }

    public function UserProfileUpdate(Request $request)
    {
        // Validate the form data
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|max:255|unique:users,email,' . Auth::user()->id,
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);

        // Get the authenticated user
        $user = Auth::user();

        // Update user details
        $user->name = $request->input('name');
        $user->email = $request->input('email');

        if ($request->hasFile('image')) {
            $imageName = 'profile' . time() . '.' . $request->image->extension();
            $request->image->move(public_path('images/user'), $imageName);

        }

        $user->image = $imageName;

        // Save the updated user information
        $user->save();

        // Redirect back with a success message
        return redirect()->back()->with('success', 'Profile updated successfully.');
    }

    public function login(){
        $languages = \App\Models\Languages::all();
        $settings = BusinessSettings::pluck('value', 'key')->toArray();
        return view('auth.user.login', compact('settings', 'languages'));
    }

    public function register(){
        $languages = \App\Models\Languages::all();
        $settings = BusinessSettings::pluck('value', 'key')->toArray();
        return view('auth.user.register', compact('settings', 'languages'));
    }


}
