<?php

// app/helpers.php

use App\Models\BusinessSettings;
use App\Models\Languages;
use App\Models\Translation;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Cookie;
use Illuminate\Support\Facades\DB;

if (!function_exists('translate')) {
    function translate($key, $locale = null)
    {
        // Default language from settings
        $defaultLang = BusinessSettings::where('key', 'default_language')->first()->value;

        // Check if a locale has been passed, otherwise use the saved locale in the session or cookie
        $locale = $locale ?: session('locale', Cookie::get('app_locale', $defaultLang));

        // Set the app locale if it's different from the current one
        if ($locale !== App::getLocale()) {
            App::setLocale($locale);  // Set the locale for the application
            Cookie::queue('app_locale', $locale, 60 * 24 * 365); // Store in cookie for 1 year
        }

        // Check if the translation already exists in the database
        $translation = Translation::where('key', $key)
                                  ->where('locale', $locale)
                                  ->first();

        // If translation doesn't exist, insert it with the default value (key itself)
        if (!$translation) {
            // Use transaction to ensure safe insertions
            DB::transaction(function () use ($key, $locale) {
                Translation::create([
                    'key' => $key,
                    'locale' => $locale, // Use current locale
                    'value' => $key // Default value is the original key with spaces
                ]);
            });

            // Return the original key with spaces as a fallback
            return $key;
        }

        // If translation exists, return its value, otherwise fallback to the sanitized key with spaces
        return $translation ? $translation->value : $key;
    }
}



if (!function_exists('currentLanguage')) {
    function currentLanguage() {
        $defaultLang = BusinessSettings::where('key', 'default_language')->first()->value;
        // Retrieve the current language code from the session or cookie
        $code = Cookie::get('app_locale', session('locale', $defaultLang)); // Default to 'en'

        // Get the languages from the database where 'status' is 1
        $langs = Languages::where('status', 1)->get();

        // Initialize an empty languages array
        $languages = [];

        // Populate the languages array dynamically
        foreach ($langs as $language) {
            $languages[$language->code] = [
                'name' => $language->name,
                'flag' => $language->app_lang_code . '.svg'
            ];
        }

        // Return the current language metadata or fall back to English
        return $languages[$code] ?? $languages[$defaultLang];
    }
}


