<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('advertisements', function (Blueprint $table) {
            $table->id(); // Primary key

            // Common Fields
            $table->string('title'); // Title of the ad
            $table->enum('type', ['adsense', 'custom'])->default('adsense'); // Type of ad: AdSense or Custom

            // AdSense Ad Fields
            $table->text('adsense_code')->nullable(); // Adsense ad code (nullable if it's a custom ad)

            // Custom Ad Fields
            $table->string('custom_image')->nullable(); // Path to the custom ad image (if it's a custom ad)
            $table->string('custom_link')->nullable(); // Link for custom ad click (optional for custom ads)
            $table->text('custom_html')->nullable(); // Any custom HTML ad content (for complex custom ads)

            // Additional Info
            $table->enum('status', ['active', 'inactive'])->default('active'); // Status: Active or Inactive
            $table->string('position')->nullable(); // Position of the ad (e.g., header, sidebar, footer)
            $table->timestamp('start_date')->nullable(); // Start date for displaying the ad
            $table->timestamp('end_date')->nullable(); // End date for displaying the ad

            $table->timestamps(); // Laravel created_at and updated_at timestamps
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('advertisements');
    }
};
