@extends('backend.layout')
@section('content')
<!-- Bootstrap CSS (if not already included) -->
<link href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css" rel="stylesheet">

<!-- Bootstrap Switch CSS -->
<link href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-switch/3.3.4/css/bootstrap3/bootstrap-switch.min.css" rel="stylesheet">

<div class="content-header">
    <div class="container-fluid">
      <div class="row mb-2">
        <div class="col-sm-6">
          <h1 class="m-0">Advertisements</h1>
        </div><!-- /.col -->
        <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right ml-1">
                <a href="{{route('admin.advertisements.create')}}" class="btn btn-primary"><i class="fa fa-plus"></i> Add New</a>
            </ol>
        </div><!-- /.col -->
      </div><!-- /.row -->
    </div><!-- /.container-fluid -->
</div>
  <!-- /.content-header -->

   <!-- Main content -->
<section class="content">
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <!-- /.card-header -->
                    <div class="card-body">

                        @if($advertisements->isEmpty())
                            <p>No advertisements found.</p>
                        @else

                            <table id="example2" class="table table-bordered table-hover">
                                <thead>
                                    <tr>
                                        <th>Title</th>
                                        <th>Type</th>
                                        <th>Status</th>
                                        <th>Position</th>
                                        <th>Start Date</th>
                                        <th>End Date</th>
                                        <th class="text-right">Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($advertisements as $ad)
                                        <tr>
                                            <td>{{ $ad->title }}</td>
                                            <td>{{ ucfirst($ad->type) }}</td> <!-- Display type with first letter capitalized -->
                                            <td>
                                                <input type="checkbox" class="status-switch" data-id="{{ $ad->id }}" {{ $ad->status === 'active' ? 'checked' : '' }} data-bootstrap-switch data-off-color="danger" data-on-color="success">
                                            </td> <!-- Display ad status -->
                                            <td>{{ $ad->position ?? 'Not Set' }}</td> <!-- Show position or 'Not Set' if null -->
                                            <td>{{ $ad->start_date ? $ad->start_date->format('Y-m-d') : 'No Start Date' }}</td> <!-- Format start date -->
                                            <td>{{ $ad->end_date ? $ad->end_date->format('Y-m-d') : 'No End Date' }}</td> <!-- Format end date -->
                                            <td class="text-right">
                                                <!-- Buttons for edit and delete -->
                                                <a href="{{ route('admin.advertisements.edit', $ad->id) }}" class="btn btn-success"><i class="fa fa-edit"></i></a>
                                                <a href="{{ route('admin.advertisements.delete', $ad->id) }}" class="btn btn-danger"><i class="fa fa-trash"></i></a>
                                            </td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        @endif
                        <!-- Pagination Links -->
                        <div class="d-flex justify-content-center mt-3">
                            {{ $advertisements->onEachSide(1)->links('pagination::bootstrap-4') }}
                        </div>

                    </div>
                    <!-- /.card-body -->
                </div>
                <!-- /.card -->
            </div>
            <!-- /.col -->
        </div>
        <!-- /.row -->
    </div>
    <!-- /.container-fluid -->
</section>

<!-- jQuery (if not already included) -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<!-- Bootstrap Switch JS -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-switch/3.3.4/js/bootstrap-switch.min.js"></script>

<script>
    $(document).ready(function() {
        $("input[data-bootstrap-switch]").each(function(){
            $(this).bootstrapSwitch();
        });

        // Handle the switch change event
        $('.status-switch').on('switchChange.bootstrapSwitch', function (event, state) {
            let categoryId = $(this).data('id');
            let isActive = state ? 'active' : 'inactive';

            $.ajax({
                url: '{{ route("admin.advertisements.toggleStatus") }}',
                type: 'POST',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: categoryId,
                    is_active: isActive
                },
                success: function(response) {
                    if(response.success) {
                        toastr.success('Status updated successfully!');
                    } else {
                        toastr.error('Status update failed.');
                    }
                },
                error: function(xhr) {
                    toastr.error('An error occurred. Please try again.');
                }
            });
        });
    });
</script>


@endsection
