@extends('backend.layout')

@section('content')
<div class="content-header">
    <div class="container-fluid">
        <div class="row mb-2">
            <div class="col-sm-6">
                <h1 class="m-0">Edit Category</h1>
            </div><!-- /.col -->
        </div><!-- /.row -->
    </div><!-- /.container-fluid -->
</div>
<!-- /.content-header -->

<section class="content">
    <div class="container-fluid">
        <div class="row">
            <div class="col-md-12 mx-auto">
                <div class="card card-primary">
                    <form action="{{ route('admin.categories.update') }}" method="POST" enctype="multipart/form-data">
                        @csrf
                        <input type="hidden" name="id" value="{{ $category->id }}">

                        <div class="card-body">
                            <!-- Category Name (English) -->
                            <div class="form-group">
                                <label for="name">Category Name (English)</label>
                                <input type="text" class="form-control" id="name" name="name" value="{{ old('name', $category->name) }}" placeholder="Enter Category Name" required>
                            </div>

                            <!-- Parent Category -->
                            <div class="form-group">
                                <label for="parent_id">Parent Category (Optional)</label>
                                <select class="form-control" name="parent_id" id="parent_id">
                                    <option value="">Select Parent Category</option>
                                    @foreach ($parentCategory as $parent)
                                        <option value="{{ $parent->id }}" @if($category->parent_id == $parent->id) selected @endif>{{ $parent->name }}</option>
                                    @endforeach
                                </select>
                            </div>

                            <!-- Category Description (English) -->
                            <div class="form-group">
                                <label for="description">Description (English)</label>
                                <textarea class="form-control" id="description" name="description" rows="4" placeholder="Enter Category Description">{{ old('description', $category->description) }}</textarea>
                            </div>

                            <h1 class="card-title text-center">Translations</h1><hr><br>

                            <!-- Language Tabs -->
                            <ul class="nav nav-tabs" id="languageTabs" role="tablist">
                                <li class="nav-item">
                                    <a class="nav-link active" id="english-tab" data-toggle="tab" href="#english" role="tab" aria-controls="english" aria-selected="true">English</a>
                                </li>
                                @foreach ($languages as $language)
                                    @if ($language->code !== "en")
                                        <li class="nav-item">
                                            <a class="nav-link" id="{{ $language->code }}-tab" data-toggle="tab" href="#{{ $language->code }}" role="tab" aria-controls="{{ $language->code }}" aria-selected="false">{{ $language->name }}</a>
                                        </li>
                                    @endif
                                @endforeach
                            </ul>

                            <div class="tab-content mt-3" id="languageTabsContent">
                                <div class="tab-pane fade show active" id="english" role="tabpanel" aria-labelledby="english-tab">
                                    <!-- Category Name (English) -->
                                    <div class="form-group">
                                        <label for="name_en">Category Name (English)</label>
                                        <input type="text" class="form-control" name="translations[en][name]" id="name_en" value="{{ old('translations.en.name', $translations['en']->name ?? '') }}" placeholder="Enter Category Name in English">
                                        <button type="button" class="btn btn-info mt-2 translateBtn" data-key="{{ $category->name }}" data-lang="{{ $language->code }}">Translate</button>
                                    </div>
                                    <!-- Category Description (English) -->
                                    <div class="form-group">
                                        <label for="description_en">Description (English)</label>
                                        <textarea class="form-control" name="translations[en][description]" id="description_en" rows="4" placeholder="Enter Description in English">{{ old('translations.en.description', $translations['en']->description ?? '') }}</textarea>
                                        <button type="button" class="btn btn-info mt-2 DesctranslateBtn" data-key="{{ old('description', $category->description) }}" data-lang="{{ $language->code }}">Translate</button>
                                    </div>
                                </div>

                                @foreach ($languages as $language)
                                    @if ($language->code !== 'en')
                                        <div class="tab-pane fade" id="{{ $language->code }}" role="tabpanel" aria-labelledby="{{ $language->code }}-tab">
                                            <!-- Category Name (Translated) -->
                                            <div class="form-group">
                                                <label for="name_{{ $language->code }}">Category Name ({{ $language->name }})</label>
                                                <input type="text" class="form-control" name="translations[{{ $language->code }}][name]"
                                                       id="name_{{ $language->code }}"
                                                       value="{{ old('translations.' . $language->code . '.name', $translations[$language->code]->name ?? '') }}"
                                                       placeholder="Enter Category Name in {{ $language->name }}">
                                                <button type="button" class="btn btn-info mt-2 translateBtn" data-key="{{ $category->name }}" data-lang="{{ $language->code }}">Translate</button>
                                            </div>
                                            <!-- Category Description (Translated) -->
                                            <div class="form-group">
                                                <label for="description_{{ $language->code }}">Description ({{ $language->name }})</label>
                                                <textarea class="form-control" name="translations[{{ $language->code }}][description]"
                                                          id="description_{{ $language->code }}" rows="4"
                                                          placeholder="Enter Description in {{ $language->name }}">
                                                    {{ old('translations.' . $language->code . '.description', $translations[$language->code]->description ?? '') }}
                                                </textarea>
                                                <button type="button" class="btn btn-info mt-2 DesctranslateBtn" data-key="{{ old('description', $category->description) }}" data-lang="{{ $language->code }}">Translate</button>
                                            </div>
                                        </div>
                                    @endif
                                @endforeach
                            </div>
                        </div>

                        <div class="card-footer text-right">
                            <button type="submit" class="btn btn-primary">Submit</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</section>

<script type="text/javascript">
    // Event listener for the "Translate" button
    document.querySelectorAll('.translateBtn').forEach(function(button) {
        button.addEventListener('click', function() {
            var key = this.getAttribute('data-key');
            var langCode = this.getAttribute('data-lang');
            var inputField = document.getElementById('name_' + langCode);
            var valueToTranslate = inputField.value.trim();

            // If textbox is empty, use the key itself for translation
            if (!valueToTranslate) {
                valueToTranslate = key; // Use the key as the translation if no value is entered
            }

            // Correct the language code for Chinese (Simplified)
            if (langCode === 'zn') {
                langCode = 'zh-CN'; // Change 'zn' to 'zh-CN' for Simplified Chinese
            }

            // Use Google Translate to get the translation for the input value
            var url = 'https://translate.googleapis.com/translate_a/single?client=gtx&sl=en&tl=' + langCode + '&dt=t&q=' + encodeURI(valueToTranslate);

            fetch(url)
                .then(response => response.json())
                .then(data => {
                    // Log the entire response to debug and inspect the structure
                    console.log('Translation Response:', data);

                    // Check if the data structure is valid
                    if (Array.isArray(data) && Array.isArray(data[0])) {
                        var translatedText = data[0][0][0]; // Extract the translated text correctly

                        // Check if the extracted translation is a string
                        if (typeof translatedText === 'string') {
                            // Clean up the response to get rid of any extra commas and metadata
                            var cleanTranslation = translatedText.split(',')[0]; // Only get the part before the first comma
                            inputField.value = cleanTranslation; // Set the clean translated text into the input field
                        } else {
                            console.error('The extracted translation is not a string:', translatedText);
                        }
                    } else {
                        console.error('Unexpected translation data structure:', data);
                    }
                })
                .catch(error => console.error('Error during translation:', error));
        });
    });

    // Event listener for translating description
    document.querySelectorAll('.DesctranslateBtn').forEach(function(button) {
        button.addEventListener('click', function() {
            var key = this.getAttribute('data-key');
            var langCode = this.getAttribute('data-lang');
            var inputField = document.getElementById('description_' + langCode);
            var valueToTranslate = inputField.value.trim();

            // If textbox is empty, use the key itself for translation
            if (!valueToTranslate) {
                valueToTranslate = key; // Use the key as the translation if no value is entered
            }

            // Correct the language code for Chinese (Simplified)
            if (langCode === 'zn') {
                langCode = 'zh-CN'; // Change 'zn' to 'zh-CN' for Simplified Chinese
            }

            // Use Google Translate to get the translation for the input value
            var url = 'https://translate.googleapis.com/translate_a/single?client=gtx&sl=en&tl=' + langCode + '&dt=t&q=' + encodeURI(valueToTranslate);

            fetch(url)
                .then(response => response.json())
                .then(data => {
                    // Log the entire response to debug and inspect the structure
                    console.log('Translation Response:', data);

                    // Check if the data structure is valid
                    if (Array.isArray(data) && Array.isArray(data[0])) {
                        var translatedText = data[0][0][0]; // Extract the translated text correctly

                        // Check if the extracted translation is a string
                        if (typeof translatedText === 'string') {
                            // Clean up the response to get rid of any extra commas and metadata
                            var cleanTranslation = translatedText.split(',')[0]; // Only get the part before the first comma
                            inputField.value = cleanTranslation; // Set the clean translated text into the input field
                        } else {
                            console.error('The extracted translation is not a string:', translatedText);
                        }
                    } else {
                        console.error('Unexpected translation data structure:', data);
                    }
                })
                .catch(error => console.error('Error during translation:', error));
        });
    });
</script>

@endsection

