@extends('backend.layout')
@section('content')
<!-- Bootstrap CSS (if not already included) -->
<link href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css" rel="stylesheet">

<!-- Bootstrap Switch CSS -->
<link href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-switch/3.3.4/css/bootstrap3/bootstrap-switch.min.css" rel="stylesheet">

<div class="content-header">
    <div class="container-fluid">
        <div class="row mb-2">
            <div class="col-sm-6">
                <h1 class="m-0">Featured Games</h1>
            </div><!-- /.col -->
            <div class="col-sm-6">
                <ol class="breadcrumb float-sm-right ml-1">
                    <a href="{{ route('admin.games.create') }}" class="btn btn-primary"><i class="fa fa-plus"></i> Add New</a>
                </ol>
            </div><!-- /.col -->
        </div><!-- /.row -->
    </div><!-- /.container-fluid -->
</div>
<!-- /.content-header -->

<!-- Main content -->
<section class="content">
    <div class="container-fluid">
        <div class="row mb-3">
            <div class="col-md-6">
                <input type="text" id="search" class="form-control" placeholder="Search by name...">
            </div>
            <div class="col-md-6">
                <select id="statusFilter" class="form-control">
                    <option value="">All Statuses</option>
                    <option value="1">Active</option>
                    <option value="0">Inactive</option>
                </select>
            </div>
        </div>

        <div class="row">
            <div class="col-12">
                <div class="card">
                    <!-- /.card-header -->
                    <div class="card-body">
                        <table id="example2" class="table table-bordered table-hover">
                            <thead>
                                <tr>
                                    <th>#</th>
                                    <th>Name</th>
                                    <th>Description</th>
                                    <th>Status</th>
                                    <th class="text-right">Action</th>
                                </tr>
                            </thead>
                            <tbody id="gameTableBody">
                                @foreach ($games as $key => $game)
                                    <tr data-status="{{ $game->status }}">
                                        <td>{{ ($games->currentPage() - 1) * $games->perPage() + $key + 1 }}</td>
                                        <td>
                                            <img src="{{ asset('images/games/icons/'.$game->image) }}" width="30">
                                            {{ $game->name }}
                                        </td>
                                        <td>{!! Str::limit($game->description, 50, '...') !!}</td>
                                        <td>
                                            <input type="checkbox" class="status-switch" data-id="{{ $game->id }}" {{ $game->status ? 'checked' : '' }} data-bootstrap-switch data-off-color="danger" data-on-color="success">
                                        </td>
                                        <td class="text-right">
                                            <a href="{{ route('game', $game->slug) }}" target="_blank" class="btn btn-primary"><i class="fa fa-eye"></i></a>
                                            <a href="{{ route('admin.games.edit', $game->id) }}" class="btn btn-success"><i class="fa fa-edit"></i></a>
                                            <a href="{{ route('admin.games.delete', $game->id) }}" class="btn btn-danger delete"><i class="fa fa-trash"></i></a>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>

                        <!-- Pagination Links -->
                        <div class="d-flex justify-content-center mt-3">
                            {{ $games->onEachSide(1)->links('pagination::bootstrap-4') }}
                        </div>
                    </div>
                    <!-- /.card-body -->
                </div>
                <!-- /.card -->
            </div>
            <!-- /.col -->
        </div>
        <!-- /.row -->
    </div>
    <!-- /.container-fluid -->
</section>

<!-- jQuery (if not already included) -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<!-- Bootstrap Switch JS -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-switch/3.3.4/js/bootstrap-switch.min.js"></script>

<script>
    $(document).ready(function() {
        $("input[data-bootstrap-switch]").each(function(){
            $(this).bootstrapSwitch();
        });

        // Handle the switch change event
        $('.status-switch').on('switchChange.bootstrapSwitch', function (event, state) {
            let categoryId = $(this).data('id');
            let status = state ? 1 : 0;

            $.ajax({
                url: '{{ route("admin.games.toggleStatus") }}',
                type: 'POST',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: categoryId,
                    status: status
                },
                success: function(response) {
                    if(response.success) {
                        toastr.success('Status updated successfully!');
                    } else {
                        alert('Status update failed.');
                    }
                },
                error: function(xhr) {
                    alert('An error occurred. Please try again.');
                }
            });
        });

        // Search functionality
        $('#search').on('keyup', function() {
            let searchTerm = $(this).val().toLowerCase();
            $('#gameTableBody tr').filter(function() {
                $(this).toggle($(this).find('td:eq(1)').text().toLowerCase().indexOf(searchTerm) > -1);
            });
        });

        // Filter functionality
        $('#statusFilter').on('change', function() {
            let selectedStatus = $(this).val();
            $('#gameTableBody tr').filter(function() {
                let status = $(this).data('status');
                if (selectedStatus === "") {
                    return true; // Show all
                }
                return status == selectedStatus;
            }).toggle();
            $('#gameTableBody tr').filter(function() {
                let status = $(this).data('status');
                if (selectedStatus === "") {
                    return false; // Hide all
                }
                return status != selectedStatus;
            }).hide();
        });
    });
</script>

@endsection
