@extends('backend.layout')

@section('content')

<!-- Bootstrap CSS (if not already included) -->
<link href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css" rel="stylesheet">
<!-- Bootstrap Switch CSS -->
<link href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-switch/3.3.4/css/bootstrap3/bootstrap-switch.min.css" rel="stylesheet">

<div class="content-header">
    <div class="container-fluid">
      <div class="row mb-2">
        <div class="col-sm-6">
          <h1 class="m-0">Languages</h1>
        </div><!-- /.col -->
        <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right ml-1">
                <a href="{{ route('admin.create.language') }}" class="btn btn-primary"><i class="fa fa-plus"></i> Add New</a>
            </ol>
        </div><!-- /.col -->
      </div><!-- /.row -->
    </div><!-- /.container-fluid -->
</div>
  <!-- /.content-header -->
<section class="content">
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        <h1 class="card-title">Choose Default Language</h1>
                        <form action="{{ route('admin.store.default.language') }}" method="POST">
                            @csrf
                            <div class="form-group">
                                <select class="form-control form-select" name="default_language" id="default_language">
                                    @foreach ($languages as $lang)
                                        <option value="{{ $lang->code }}" @if($defaultLanguage->value == $lang->code) selected @endif>{{ $lang->name }}</option>
                                    @endforeach
                                </select>
                            </div>
                            <div class="form-group text-right">
                                <button type="submit" class="btn btn-primary">Save</button>
                            </div>
                        </form>
                    </div>
                </div>
                <div class="card">
                    <!-- /.card-header -->
                    <div class="card-body">
                        <table class="table table-bordered">
                            <thead>
                                <tr>
                                    <th>Name</th>
                                    <th>code</th>
                                    <th>RTL Support</th>
                                    <th>Status</th>
                                    <th class="text-right">Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach($languages as $language)
                                    <tr>
                                        <td>{{ $language->name }}</td>
                                        <td>{{ $language->code }}</td>
                                        <td>
                                            <input type="checkbox" class="rtl-switch" data-id="{{ $language->id }}" {{ $language->rtl ? 'checked' : '' }} data-bootstrap-switch data-off-color="danger" data-on-color="success">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="status-switch" data-id="{{ $language->id }}" {{ $language->status ? 'checked' : '' }} data-bootstrap-switch data-off-color="danger" data-on-color="success">
                                        </td>
                                        <td class="text-right">

                                            <a href="{{route('translations.index', $language->id)}}" class="btn btn-warning" title="Translate"><i class="fa fa-language"></i></a>
                                            <!-- Edit Button -->
                                            <a href="{{ route('admin.edit.language', $language->id) }}" class="btn btn-success"><i class="fa fa-edit"></i></a>

                                            <!-- Delete Form -->
                                            <form action="{{ route('admin.delete.language', $language->id) }}" method="POST" style="display:inline-block;">
                                                @csrf
                                                <!-- Since the route is using POST, we don't need @method('DELETE') -->
                                                <button type="submit" class="btn btn-danger delete"><i class="fa fa-trash"></i></button>
                                            </form>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- Bootstrap Switch JS -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-switch/3.3.4/js/bootstrap-switch.min.js"></script>

<script>
    $(document).ready(function() {
        $("input[data-bootstrap-switch]").each(function(){
            $(this).bootstrapSwitch();
        });

        // Handle the switch change event
        $('.status-switch').on('switchChange.bootstrapSwitch', function (event, state) {
            let categoryId = $(this).data('id');
            let status = state ? 1 : 0;

            $.ajax({
                url: '{{ route("admin.languages.toggleStatus") }}',
                type: 'POST',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: categoryId,
                    status: status
                },
                success: function(response) {
                    if(response.success) {
                        toastr.success('Status updated successfully!');
                    } else {
                        toastr.error('Status update failed.');
                    }
                },
                error: function(xhr) {
                    toastr.error('An error occurred. Please try again.');
                }
            });
        });

        $('.rtl-switch').on('switchChange.bootstrapSwitch', function (event, state) {
            let categoryId = $(this).data('id');
            let rtl = state ? 1 : 0;

            $.ajax({
                url: '{{ route("admin.languages.toggleRtl") }}',
                type: 'POST',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: categoryId,
                    rtl: rtl
                },
                success: function(response) {
                    if(response.success) {
                        toastr.success('Status updated successfully!');
                    } else {
                        toastr.error('Status update failed.');
                    }
                },
                error: function(xhr) {
                    toastr.error('The RTL feature will be available soon.');
                }
            });
        });

    });
</script>
@endsection
