@extends('backend.layout')

@section('content')
<div class="content-header">
    <div class="container-fluid">
        <div class="row mb-2">
            <div class="col-sm-6">
                <h1 class="m-0">Create Menu Items</h1>
            </div><!-- /.col -->
        </div><!-- /.row -->
    </div><!-- /.container-fluid -->
</div>
<!-- /.content-header -->

<section class="content">
    <div class="container-fluid">

        <form action="{{ route('admin.menus.store.item') }}" method="POST" enctype="multipart/form-data">
            @csrf
            <div class="row">
                <!-- left column -->
                <div class="col-md-12">
                    <!-- general form elements -->
                    <div class="card card-primary">
                        <div class="card-body">
                            <div class="row">
                                <input type="hidden" name="menu_id" value="{{ $menu_Id }}">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="title">Title</label>
                                        <input type="text" name="title" class="form-control" required>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="url">URL</label>
                                        <input type="text" name="url" class="form-control">
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="card-footer text-right">
                            <button type="submit" class="btn btn-primary">Create</button>
                        </div>
                    </div>
                </div>
            </div>
        </form>

        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        <ul id="sortable" class="list-group">
                            @foreach ($menuItems as $item)
                                <li class="list-group-item" data-id="{{ $item->id }}">
                                    <span>
                                        <svg xmlns="http://www.w3.org/2000/svg" width="32" height="16" fill="currentColor" class="bi bi-grip-vertical" viewBox="0 0 32 16">
                                        <path d="M7 2a1 1 0 1 1-2 0 1 1 0 0 1 2 0m3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0M7 5a1 1 0 1 1-2 0 1 1 0 0 1 2 0m3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0M7 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0m3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0m-3 3a1 1 0 1 1-2 0 1 1 0 0 1 2 0m3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0m-3 3a1 1 0 1 1-2 0 1 1 0 0 1 2 0m3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0"/>
                                      </svg>
                                    </span>
                                    <span class="menu-title">{{ $item->title }}</span>
                                    <span class="menu-url badge badge-success" style="font-size: 14px;">{{ $item->url }}</span>
                                    <div class="float-right">
                                        <a href="{{route('admin.menus.editItem', $item->id)}}" class="btn btn-success btn-sm"><i class="fa fa-edit"></i></a>
                                        <a href="{{route('admin.menus.destroyItem', $item->id)}}" class="btn btn-danger btn-sm delete"><i class="fa fa-trash"></i></a>
                                    </div>
                                </li>
                            @endforeach
                        </ul>
                        <button class="btn btn-primary mt-3" id="saveOrder">Save Order</button>
                    </div>
                </div>
            </div>
        </div>

    </div>
</section>

<!-- jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<!-- jQuery UI -->
<script src="https://code.jquery.com/ui/1.12.1/jquery-ui.min.js"></script>

<script>
    var jq = $.noConflict();
    jq(function() {
        console.log("Initializing sortable...");

        // Make the list items sortable
        jq("#sortable").sortable({
            placeholder: "ui-state-highlight",
            update: function(event, ui) {
                console.log("Updated order");

                var order = [];
                jq('#sortable li').each(function(index, element) {
                    order.push({
                        id: jq(this).data('id'),
                        position: index + 1
                    });
                });

                // Enable the save button when the order is updated
                jq('#saveOrder').prop('disabled', false);

                // Save order via AJAX
                jq('#saveOrder').click(function() {
                    console.log("Saving order...");

                    jq.ajax({
                        url: '{{ route("admin.menus.saveOrder") }}',
                        method: 'POST',
                        data: {
                            _token: '{{ csrf_token() }}',
                            order: order
                        },
                        success: function(response) {
                            toastr.success(response.message);
                        },
                        error: function(xhr) {
                            toastr.error('An error occurred while saving the order.');
                        }
                    });
                });
            }
        });

        // Ensure that jQuery UI is loading and sortable is initialized
        if (jq.ui) {
            console.log("jQuery UI is loaded.");
        } else {
            console.log("jQuery UI failed to load.");
        }
    });
</script>


@endsection



