@extends('backend.layout')

@section('content')

<!-- Bootstrap CSS (if not already included) -->
<link href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css" rel="stylesheet">
<!-- Bootstrap Switch CSS -->
<link href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-switch/3.3.4/css/bootstrap3/bootstrap-switch.min.css" rel="stylesheet">

<div class="content-header">
    <div class="container-fluid">
      <div class="row mb-2">
        <div class="col-sm-6">
          <h1 class="m-0">Translations</h1>
        </div>
      </div><!-- /.row -->
    </div><!-- /.container-fluid -->
</div>
  <!-- /.content-header -->
<section class="content">
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <!-- /.card-header -->
                    <div class="card-body">
                        <form method="POST" action="{{ route('translations.store') }}">
                            @csrf
                            <table class="table table-bordered">
                                <thead>
                                    <tr>
                                        <th>Key</th>
                                        <th>Value</th>
                                        <th>Action</th> <!-- New column for Translate button -->
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($translations->groupBy('key') as $key => $group)
                                        <tr>
                                            <td>{{ $key }}</td>
                                            @php
                                                $langTranslation = $group->where('locale', $language->code)->first();
                                            @endphp
                                            <td>
                                                <input class="form-control" type="text" name="translation[{{ $key }}][{{ $language->code }}]" id="translation-{{ $key }}" placeholder="Enter translation" value="{{ $langTranslation ? $langTranslation->value : '' }}">
                                            </td>
                                            <td>
                                                <button type="button" class="btn btn-info translateBtn" data-key="{{ $key }}" data-lang="{{ $language->code }}">Translate</button> <!-- Translate button for each row -->
                                            </td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                            <div class="text-right">
                                <button type="submit" class="btn btn-primary">Save Translations</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- Bootstrap Switch JS -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-switch/3.3.4/js/bootstrap-switch.min.js"></script>

<script type="text/javascript">
    // Event listener for the "Translate" button
    document.querySelectorAll('.translateBtn').forEach(function(button) {
        button.addEventListener('click', function() {
            var key = this.getAttribute('data-key');
            var langCode = this.getAttribute('data-lang');
            var inputField = document.getElementById('translation-' + key);
            var valueToTranslate = inputField.value.trim();

            // If textbox is empty, use the key itself for translation
            if (!valueToTranslate) {
                valueToTranslate = key; // Use the key as the translation if no value is entered
            }

            // Correct the language code for Chinese (Simplified)
            if (langCode === 'zn') {
                langCode = 'zh-CN'; // Change 'zn' to 'zh-CN' for Simplified Chinese
            }

            // Use Google Translate to get the translation for the input value
            var url = 'https://translate.googleapis.com/translate_a/single?client=gtx&sl=en&tl=' + langCode + '&dt=t&q=' + encodeURI(valueToTranslate);

            fetch(url)
                .then(response => response.json())
                .then(data => {
                    // Log the entire response to debug and inspect the structure
                    // console.log('Translation Response:', data);

                    // Check if the data structure is valid
                    if (Array.isArray(data) && Array.isArray(data[0])) {
                        var translatedText = data[0][0][0]; // Extract the translated text correctly

                        // Check if the extracted translation is a string
                        if (typeof translatedText === 'string') {
                            // Clean up the response to get rid of any extra commas and metadata
                            var cleanTranslation = translatedText.split(',')[0]; // Only get the part before the first comma
                            inputField.value = cleanTranslation; // Set the clean translated text into the input field
                        } else {
                            console.error('The extracted translation is not a string:', translatedText);
                        }
                    } else {
                        console.error('Unexpected translation data structure:', data);
                    }
                })
                .catch(error => console.error('Error during translation:', error));
        });
    });
</script>

<script>
    $(document).ready(function() {
        $("input[data-bootstrap-switch]").each(function(){
            $(this).bootstrapSwitch();
        });

        // Handle the switch change event
        $('.status-switch').on('switchChange.bootstrapSwitch', function (event, state) {
            let categoryId = $(this).data('id');
            let isActive = state ? 1 : 0;

            $.ajax({
                url: '{{ route("admin.blog.categories.toggleStatus") }}',
                type: 'POST',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: categoryId,
                    is_active: isActive
                },
                success: function(response) {
                    if(response.success) {
                        toastr.success('Status updated successfully!');
                    } else {
                        toastr.error('Status update failed.');
                    }
                },
                error: function(xhr) {
                    toastr.error('An error occurred. Please try again.');
                }
            });
        });
    });
</script>
@endsection
