@extends('frontend.layout')
@section('content')

<style>
    #blog-container {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
    }

    /* Blog Posts Section */
    .blog-post {
        border: 1px solid #ddd;
        border-radius: 8px;
        overflow: hidden;
        transition: transform 0.3s ease;
        background: #fff;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    .blog-post img {
        width: 100%;
        height: 500px;
        object-fit: cover;
    }

    .blog-post:hover {
        transform: translateY(-5px);
        box-shadow: 0 4px 10px rgba(0, 0, 0, 0.15);
    }

    .blog-post h3 {
        font-size: 1.5rem;
        margin: 15px;
        text-transform: capitalize;
        color: #333;
    }

    .blog-post p {
        margin: 0 15px 15px;
        color: #555;
    }

    .blog-post .btn {
        margin: 15px;
        display: block;
    }

    /* Sidebar Section */
    .sidebar {
        padding: 20px;
        background: #f8f9fa;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
    }

    .sidebar h4 {
        font-size: 1.25rem;
        margin-bottom: 20px;
        color: #333;
        text-align: center;
    }

    .sidebar .card {
        margin-bottom: 15px;
        cursor: pointer;
        transition: transform 0.2s ease;
    }

    .sidebar .card:hover {
        transform: scale(1.05);
    }

    .sidebar .card-img-top {
        height: 100px;
        object-fit: cover;
        border-radius: 8px;
    }

    .sidebar .card-title {
        font-size: 1rem;
        margin: 10px 0;
        color: #444;
    }

    #game-display {
        display: flex;
        gap: 20px;
        padding: 20px;
        flex-wrap: wrap;
    }

    .card {
        position: relative;
        overflow: hidden;
    }

    .card-body {
        position: absolute;
        bottom: 0;
        left: 0;
        right: 0;
        background-color: rgba(0, 0, 0, 0.6);
        color: white;
        padding: 10px;
        opacity: 0;
        transition: opacity 0.3s ease;
    }

    .card-img-top {
        width: 100%;
        height: auto;
        object-fit: cover;
    }

    .card:hover .card-img-top {
        transform: scale(1.1);
    }

    .card:hover .card-body {
        opacity: 1;
    }

    #game-display .game-play-area,
    #game-display .game-info {
        flex: 1;
        max-width: 50%;
    }

    .fixed-size-image {
        width: 100%;
        height: auto;
        object-fit: cover;
        border-radius: 8px;
    }

    p{
        color:#333!important;
    }

    @media (max-width: 768px) {

        #game-display .game-play-area,
        #game-display .game-info {
            max-width: 100%;
        }
        #game-display .game-info {
            margin-top: 20px;
        }
        .game-play-area{
            max-width: 100%;
            width: 100%;
        }

        #blog-container {
            flex-direction: column;
        }
        .blog-post img {
            width: 100%;
            height: 200px;
            object-fit: cover;
        }

        .sidebar {
            margin-top: 20px;
        }
    }
</style>

<div class="container mt-4">
    <div class="row">
        <!-- Blog Posts Section -->
        <div class="col-md-8">
            <div class="blog-post">
                <h3>{{ $blogpost->title }}</h3>
                <p>Published on: <span>{{ \Carbon\Carbon::parse($blogpost->published_at)->format('d F Y') }}</span></p>

                <img src="{{ asset('images/posts/' . $blogpost->featured_image) }}" alt="{{ $blogpost->title }}">

                <p>{!! $blogpost->content !!}</p>
            </div>
        </div>

        <!-- Sidebar Section -->
        <div class="col-md-4 p-2">
            <h2 class="text-truncate"> {{translate('Recent Games')}} </h2>

            <div class="co-md-12 mt-3">
                <div class="row">
                    @foreach($recentGames->take(40) as $game)
                        <div class="col-md-3 mb-4">
                            <div class="card" style="cursor: pointer;" onclick="location.href='{{ route('game', $game->slug) }}'">
                                <img src="{{ asset('images/games/icons/' . $game->image) }}" class="card-img-top" alt="{{ $game->name }}">
                                <div class="card-body text-center">
                                    <h6 class="card-title">{{ $game->name }}</h6>
                                </div>
                            </div>
                        </div>
                    @endforeach
                </div>
            </div>

        </div>
    </div>
</div>

@endsection
