<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{{$blogpost->title}} - {{ old('website_name', $settings['website_name'] ?? '') }}</title>


    <meta name="description" content="{{$blogpost->meta_description ?? ''}}">
    @php
        $tags = json_decode($blogpost->meta_keywords, true);
    @endphp

    <meta name="keywords" content="{{ implode(', ', $tags ?? '') }}">


    <!-- Meta Image for Social Sharing -->
    <meta property="og:title" content="{{$blogpost->title}} - {{ old('website_name', $settings['website_name'] ?? '') }}">
    <meta property="og:description" content="{{$blogpost->meta_description ?? ''}}">
    <meta property="og:image" content="{{asset('images/posts/' . $blogpost->featured_image ?? '')}}">
    <meta property="og:url" content="{{ url('blog/' . $blogpost->slug ?? '') }}">

    {!! $settings['google_analytics'] !!}

    <!-- Twitter Meta Tags -->
    <meta name="twitter:card" content="{{asset('images/posts/' . $blogpost->featured_image ?? '')}}">
    <meta name="twitter:title" content="{{$blogpost->title}} - {{ old('website_name', $settings['website_name'] ?? '') }}">
    <meta name="twitter:description" content="{{$blogpost->meta_descriptio ?? ''}}">
    <meta name="twitter:image" content="{{asset('images/posts/' . $blogpost->featured_image ?? '')}}">

    <!-- Canonical URL (for SEO) -->
    <link rel="canonical" href="{{ url('blog/' . $blogpost->slug ?? '') }}">


    <link rel="stylesheet" href="{{asset('frontend/css/setting.css')}}">

    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="{{asset('frontend/css/style.css')}}">
    <style>
        .category-name {
            font-size: 16px;
            color: #d47217;
            top: 0;
        }

        .category-scroll-container {
            overflow-x: auto;
            white-space: nowrap;
            scrollbar-width: none;
        }

        .category-scroll-container::-webkit-scrollbar {
            display: none; /* Hide scrollbar for webkit browsers */
        }

        body {
            background-color: #121212;
            color: #f0f0f0;
        }

        .btn-primary {
            background-color: #ffcc00;
            border: none;
            color: #f0f0f0;
            font-weight: bold;
            text-transform: uppercase;
            letter-spacing: 1px;
        }

        .btn-primary:hover {
            background-color: #e6b800;
        }

        .ratio-16x9 iframe {
            border: 2px solid #ffcc00;
            border-radius: 5px;
        }

        .bg-light {
            background-color: #1e1e1e !important;
            color: #f0f0f0;
        }


    </style>
    <link href="https://fonts.googleapis.com/css2?family=Orbitron:wght@400;700&display=swap" rel="stylesheet">
</head>

<body>

    <!-- Header -->
    @include('frontend.partials._header')

    <!-- Game Area -->
    <div class="container-fluid my-4">
        <div class="row">
            <div class="col-md-12">
                <div class="category-scroll-container" id="categoryScrollContainer">
                    <div class="d-flex flex-nowrap">
                        <!-- Category 1 -->
                        @foreach ($recentGames as $recent)
                            <div class="text-center me-4">
                                <a style="text-decoration: none;color:#f0f0f0;" href="{{route('game.play', $recent->slug)}}">
                                    <img src="{{asset('images/games/icons/' . $recent->image)}}" class="card-img-top mx-auto" style="border-radius: 5px; width: 80px; height: 80px; object-fit: cover;">
                                    <p>{{ Str::limit($recent->name, 15, '...')}}</p>
                                </a>
                            </div>
                        @endforeach
                    </div>
                </div>
            </div>

            <div class="col-md-12">
                <div class="row">
                    <div class="col-lg-2 col-md-3 col-sm-12 mb-4 d-none d-lg-block">
                        <div class="row">
                            @foreach ($mostplayedGames as $mostplayed)
                                <div class="col-md-6 text-center">
                                    <a class="text-white" style="text-decoration: none;" href="{{route('game.play', $mostplayed->slug)}}">
                                        <img style="border-radius: 10px; width:100%;height:120px;" class="card-img-top mx-auto" src="{{asset('images/games/icons/' . $mostplayed->image)}}" loading="lazy">
                                        <p>{{$mostplayed->name}}</p>
                                    </a>
                                </div>
                            @endforeach
                        </div>
                    </div>

                    <div class="col-md-7">
                        <div class="ratio ratio-16x9">
                            <img src="{{asset('images/posts/' . $blogpost->featured_image)}}" frameborder="0" />
                        </div>
                        <div class="d-flex justify-content-between align-items-center mt-3">
                            <div>
                                <h3>{{ $blogpost->title }}</h3>
                            </div>

                        </div>
                        <p class="mt-4 text-light" style="color: white;">{!! $blogpost->content !!}</p>

                    </div>
                    <div class="col-md-3">
                        <!-- Ad Space -->
                        <div class="bg-light p-4 mb-4">
                            <h5>{{translate('Advertisement')}}</h5>
                            <img src="https://fakeimg.pl/400x400?text=Ad" class="img-fluid w-100" alt="Ad Placeholder">
                        </div>
                        <!-- Game Info Panel -->
                        <div class="bg-light p-4">
                            <h5>{{translate('Game Information')}}</h5>
                            <ul>
                                <li>Mouse/Touchpad: Most HTML5 games use the mouse or touchpad for primary interactions. For example:</li>
                                    <ul>
                                        <li>Click: Click to select options, start the game, or perform actions like shooting or jumping.</li>
                                        <li>Drag and Drop: For games involving dragging elements, hold the left mouse button and move the mouse to drag objects.</li>
                                    </ul>
                                <li>Keyboard: Some games might require keyboard input. Common controls include:</li>
                                    <ul>
                                        <li>Arrow Keys (↑, ↓, ←, →): Move your character, navigate menus, or control in-game movement.</li>
                                        <li>Spacebar: Often used for actions like jumping, shooting, or pausing the game.</li>
                                        <li>Enter/Return: Start the game or confirm selections.</li>
                                        <li>Esc: Pause the game or access the game menu.</li>
                                    </ul>
                                <li>Game Objectives:</li>
                                    <ul>
                                        <li>Read the game’s objective, usually provided on the start screen or within a tutorial.</li>
                                        <li>Follow any in-game prompts or tutorials that guide you through the first few levels or actions.</li>
                                    </ul>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    @if(env('DEMO_MODE') == 'on')

        <!-- Floating Settings Button -->
        <div id="settingsButton" onclick="openThemeModal()">⚙️ {{translate('Themes')}}</div>

        <!-- Theme Modal -->
        <div id="themeModal" class="theme-modal">
            @php
                $theme = App\Models\BusinessSettings::where('key', 'theme')->first()->value;
            @endphp
            <div class="modal-content">
                <span class="close-btn" onclick="closeThemeModal()">&times;</span>
                <h4>{{translate('Choose Theme')}}</h4>
                <hr>
                <section id="game-list">
                    <div class="theme-card" data-theme="playverse" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gameverse.jpg')}}" alt="PlayVerse">
                        <div class="theme-title">
                            <h6>PlayVerse</h6>
                            @if($theme == 'playverse')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                    <div class="theme-card" data-theme="gamehive" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gamehive.jpg')}}" alt="GameHive">
                        <div class="theme-title">
                            <h6>GameHive</h6>
                            @if($theme == 'gamehive')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                    <div class="theme-card" data-theme="gamegalore" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gamegalore.jpg')}}" alt="GameGalore">
                        <div class="theme-title">
                            <h6>GameGalore</h6>
                            @if($theme == 'gamegalore')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                </section>
            </div>
        </div>

    @endif

    <!-- Footer -->
    @include('frontend.partials._footer')

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            const scrollContainer = document.getElementById('categoryScrollContainer');

            let scrollAmount = 0;
            function autoScroll() {
                scrollAmount += 1; // Adjust this value for speed
                scrollContainer.scrollLeft = scrollAmount;

                if (scrollAmount >= scrollContainer.scrollWidth - scrollContainer.clientWidth) {
                    scrollAmount = 0; // Reset to start if reached the end
                }
            }

            setInterval(autoScroll, 50); // Adjust the interval for speed
        });
    </script>

    <script>
        function openThemeModal() {
            document.getElementById('themeModal').style.display = 'flex';
        }

        function closeThemeModal() {
            document.getElementById('themeModal').style.display = 'none';
        }
    </script>

    <script>
        document.querySelectorAll('.theme-card').forEach(card => {
            card.addEventListener('click', function() {
                const selectedTheme = this.getAttribute('data-theme');

                fetch('{{route('set.theme')}}', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                        'X-CSRF-TOKEN': '{{ csrf_token() }}' // Include CSRF token
                    },
                    body: JSON.stringify({ theme: selectedTheme })
                })
                .then(response => {
                    if (!response.ok) {
                        throw new Error('Network response was not ok');
                    }
                    return response.json();
                })
                .then(data => {
                    if (data.success) {
                        location.reload();
                    } else {
                        alert('Failed to change theme');
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                });
            });
        });
    </script>

</body>

</html>
