@php
    $theme = App\Models\BusinessSettings::where('key', 'theme')->first()->value;
@endphp
@extends('frontend.layout')
@if($theme == 'playverse')
<title>{{ Auth::user()->name }} - HTML Games</title>
@section('content')

<!-- Custom CSS -->
<style>
    .profile-image-container {
        width: 150px;
        height: 150px;
        position: relative;
        margin: 0 auto;
    }

    .profile-image {
        object-fit: cover;
        border: 2px solid #ddd;
    }

    .edit-icon {
        bottom: 10px;
        right: 15px;
        display: none;
        background-color: rgba(0, 0, 0, 0.7);
        border: none;
        padding: 5px 10px;
        border-radius: 50%;
    }

    .profile-image-container:hover .edit-icon {
        display: block;
    }

    /* Card customization */
    .card {
        background-color: #343a40;
        border-radius: 10px;
    }

    .form-label {
        color: #f8f9fa;
    }

    .form-control {
        background-color: #495057;
        color: #fff;
        border: none;
    }

    .form-control:focus {
        background-color: #495057;
        color: #fff;
        border: 1px solid #6c757d;
        box-shadow: none;
    }

    .btn-primary {
        background-color: #007bff;
        border-color: #007bff;
    }

    .btn-primary:hover {
        background-color: #0056b3;
        border-color: #004085;
    }
</style>

    <div class="container-fluid my-5">
        <h2 class="text-center">{{ Auth::user()->name }} - {{translate('Profile')}}</h2>

        <div class="card card-bordered text-white m-2 p-2">
            <div class="card-header text-center">
                <h3>{{translate('Update Profile Details')}}</h3>
                <hr class="m-3">
            </div>

            <div class="card-body">
                <!-- Profile Image Section -->
                <div class="text-center mb-4 position-relative profile-image-container">
                    <img id="profile-image"
                         src="{{ $user->image ? asset('images/user/' . $user->image) : asset('images/default-avatar.avif') }}"
                         class="rounded-circle profile-image"
                         width="150"
                         height="150"
                         alt="Profile Image">

                    <button id="edit-image-btn" class="btn btn-info position-absolute edit-icon">
                        <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-pencil" viewBox="0 0 16 16">
                            <path d="M12.146.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1 0 .708l-10 10a.5.5 0 0 1-.168.11l-5 2a.5.5 0 0 1-.65-.65l2-5a.5.5 0 0 1 .11-.168zM11.207 2.5 13.5 4.793 14.793 3.5 12.5 1.207zm1.586 3L10.5 3.207 4 9.707V10h.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.5h.293zm-9.761 5.175-.106.106-1.528 3.821 3.821-1.528.106-.106A.5.5 0 0 1 5 12.5V12h-.5a.5.5 0 0 1-.5-.5V11h-.5a.5.5 0 0 1-.468-.325"/>
                        </svg>
                    </button>
                </div>

                <!-- Update Profile Form -->
                <form action="{{ route('user.profile.update') }}" method="POST" enctype="multipart/form-data">
                    @csrf
                    <input type="file" id="profile-image-input" name="image" accept="image/*" class="d-none">
                    <div class="col-md-8 mx-auto mb-3">
                        <label class="form-label" for="name">{{translate('Name')}}: </label>
                        <input type="text" class="form-control" name="name" value="{{ $user->name }}" id="name" placeholder="{{translate('User Name')}}" required>
                    </div>
                    <div class="col-md-8 mx-auto mt-3">
                        <label class="form-label" for="email">{{translate('Email Address')}}: </label>
                        <input type="email" class="form-control" name="email" value="{{ $user->email }}" id="email" placeholder="{{translate('User Email')}}" required>
                    </div>

                    <div class="text-end mt-4">
                        <button class="btn btn-primary" type="submit">{{translate('Update Profile')}}</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- JavaScript for Image Picker -->
    <script>
        document.getElementById('edit-image-btn').addEventListener('click', function() {
            document.getElementById('profile-image-input').click();
        });

        document.getElementById('profile-image-input').addEventListener('change', function(event) {
            if (event.target.files.length > 0) {
                var reader = new FileReader();
                reader.onload = function(e) {
                    document.getElementById('profile-image').src = e.target.result;
                };
                reader.readAsDataURL(event.target.files[0]);
            }
        });
    </script>

@endsection

@elseif($theme == 'gamehive' || $theme == 'gamegalore')
@section('content')
<div class="container mt-5">
    <section id="profile-update">
        <div class="row justify-content-center">
            <div class="col-md-10 col-lg-8">
                <div class="card shadow-sm border-0">
                    <div class="card-header text-white text-center" style="background: #034261;">
                        <h4 class="mb-0">{{translate('Update Profile')}}</h4>
                    </div>
                    <div class="card-body p-2">
                        <form class="card p-5 mb-2" action="{{ route('user.profile.update') }}" method="POST" enctype="multipart/form-data">
                            @csrf
                            <div class="text-center mb-4 gap-2 d-flex flex-column align-items-center">
                                <!-- Profile Image Preview -->
                                <img id="profileImagePreview" src="{{ $user->image ? asset('images/user/' . $user->image) : asset('images/default-avatar.avif') }}"
                                    alt="Profile Image" class="rounded-circle img-thumbnail"
                                    style="width: 150px; height: 150px;">

                                <label class="btn btn-outline-secondary btn-sm">
                                    {{translate('Change Image')}}
                                    <input type="file" id="profileImage" name="image" accept="image/*" class="d-none" onchange="previewImage(event)">
                                </label>
                            </div>

                            <!-- Name Field -->
                            <div class="form-group mb-3">
                                <label for="name" class="form-label">{{translate('Name')}}</label>
                                <input type="text" id="name" name="name"
                                       class="form-control @error('name') is-invalid @enderror"
                                       value="{{ old('name', auth()->user()->name) }}" required>
                                @error('name')
                                    <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                @enderror
                            </div>

                            <!-- Email Field -->
                            <div class="form-group mb-3">
                                <label for="email" class="form-label">{{translate('Email')}}</label>
                                <input type="email" id="email" name="email"
                                       class="form-control @error('email') is-invalid @enderror"
                                       value="{{ old('email', auth()->user()->email) }}" required>
                                @error('email')
                                    <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                @enderror
                            </div>
                            <!-- Submit Button -->
                            <div class="form-group mb-2 text-center">
                                <button type="submit" class="btn btn-primary w-100">{{translate('Update Profile')}}</button>
                            </div>
                        </form>

                        <form class="card p-5 mb-2" method="post" action="{{ route('password.update') }}">
                            @csrf
                            @method('put')

                            <!-- Old Password Field -->
                            <div class="form-group mb-3">
                                <label for="current_password" class="form-label">{{translate('Current Password')}}</label>
                                <input type="password" id="current_password" name="current_password"
                                       class="form-control @error('current_password') is-invalid @enderror" required>
                                @error('current_password')
                                    <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                @enderror
                            </div>

                            <!-- New Password Field -->
                            <div class="form-group mb-3">
                                <label for="password" class="form-label">{{translate('New Password')}}</label>
                                <input type="password" id="password" name="password"
                                       class="form-control @error('password') is-invalid @enderror">
                                @error('password')
                                    <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                @enderror
                            </div>

                            <!-- Password Confirmation Field -->
                            <div class="form-group mb-3">
                                <label for="password_confirmation" class="form-label">{{translate('Confirm New Password')}}</label>
                                <input type="password" id="password_confirmation" name="password_confirmation"
                                       class="form-control">
                            </div>

                            <!-- Submit Button -->
                            <div class="form-group mb-0 text-center">
                                <button type="submit" class="btn btn-primary w-100">{{translate('Update Password')}}</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </section>
</div>

<!-- Image Preview Script -->
<script>
    function previewImage(event) {
        const input = event.target;
        const reader = new FileReader();
        reader.onload = function() {
            const imgElement = document.getElementById('profileImagePreview');
            imgElement.src = reader.result;
        };
        reader.readAsDataURL(input.files[0]);
    }
</script>
@endsection
@endif
