<?php
    // Fetch the main menu value from BusinessSettings
    $mainMenu = App\Models\BusinessSettings::where('key', 'main_menu')->first();
    if ($mainMenu && $mainMenu->value) {
        // Fetch the menu using the value from the main menu settings
        $selectedMenu = App\Models\Menus::where('id', $mainMenu->value)->first();
    }
    $menuItems = App\Models\MenuItems::where('menu_id', $selectedMenu->id)->orderBy('order', 'asc')->get();

    $loginEnabled = App\Models\BusinessSettings::where('key', 'header_login')->first()->value;
    $searchEnabled = App\Models\BusinessSettings::where('key', 'header_search')->first()->value;
    $logo = App\Models\BusinessSettings::where('key', 'website_logo')->first()->value;
    $websiteName = App\Models\BusinessSettings::where('key', 'website_name')->first()->value;
    $languages = \App\Models\Languages::where('status', 1)->get();
?>


<header class="header">
    <div class="header-content">
        <div class="main-head">
            <!-- Logo -->
            <div class="logo">
                <?php if($logo == null): ?>
                    <a href="<?php echo e(route('home')); ?>" style="text-decoration: none; color:#ffffff;">
                        <h1 style="font-weight: 600; font-size: 30px;"><?php echo e($websiteName); ?></h1>
                    </a>
                <?php else: ?>
                    <a href="<?php echo e(route('home')); ?>" style="text-decoration: none; color:#ffffff;">
                        <img src="<?php echo e(asset('images/logos/'.$logo)); ?>" width="100">
                    </a>
                <?php endif; ?>
            </div>

            <!-- Drawer Toggle Button (Visible in Mobile View) -->
            <button id="drawer-toggle" class="drawer-toggle">☰</button>

            <!-- Navigation Menu (Hidden in Mobile View) -->
            <nav class="nav-menu">
                <ul id="categories" class="swipe-menu">
                    <?php $__currentLoopData = $menuItems; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $item): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        <li class="<?php echo e(Request::is(trim($item->url, '/')) ? 'active' : ''); ?>">
                            <a class="nav-link" href="<?php echo e($item->url); ?>">
                                <?php echo e(translate($item->title)); ?>

                            </a>
                        </li>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

                </ul>
            </nav>

            <div class="d-flex">
                <?php if($loginEnabled == 1): ?>
                    <?php if(auth()->guard()->check()): ?>
                        <div class="dropdown ms-1 m-1 mt-2 d-none d-md-block">
                            <button class="btn btn-secondary dropdown-toggle" type="button" id="userMenuDropdown" data-bs-toggle="dropdown" aria-expanded="false">
                                <img src="<?php echo e(Auth::user()->image ? asset('images/user/' . Auth::user()->image) : asset('images/default-avatar.avif')); ?>" width="30" height="30" class="rounded-circle ms-2">
                            </button>


                            <ul class="dropdown-menu" aria-labelledby="userMenuDropdown">
                                <li><a class="dropdown-item" href="<?php echo e(route('user.profile')); ?>"><i class="bi bi-user"></i><?php echo e(translate('Profile')); ?></a></li>
                                <li><a class="dropdown-item" href="<?php echo e(route('user.liked')); ?>"><?php echo e(translate('Liked Games')); ?></a></li>
                                <li><a class="dropdown-item" href="<?php echo e(route('user.history')); ?>"><?php echo e(translate('History')); ?></a></li>
                                <li><hr class="dropdown-divider"></li>
                                <li>
                                    <a class="dropdown-item" href="<?php echo e(route('logout')); ?>"
                                        onclick="event.preventDefault(); document.getElementById('logout-form').submit();">
                                        <?php echo e(translate('Logout')); ?>

                                    </a>
                                    <form id="logout-form" action="<?php echo e(route('logout')); ?>" method="POST" class="d-none">
                                        <?php echo csrf_field(); ?>
                                    </form>
                                </li>
                            </ul>
                        </div>
                    <?php endif; ?>

                    <?php if(auth()->guard()->guest()): ?>
                        <!-- Login and Register Buttons (Hidden in Mobile View) -->
                        <div class="accounts">
                            <a href="<?php echo e(route('user.login')); ?>" style="text-decoration: none; background:transparent;" class="btn btn-secondary login-btn"><?php echo e(translate('Login')); ?></a>
                        </div>
                    <?php endif; ?>
                <?php endif; ?>

                <div class="dropdown ms-1 m-1 mt-2 text-center d-none d-md-block">
                    <button style="background:transparent;" class="btn btn-secondary dropdown-toggle" type="button" id="userMenuDropdown" data-bs-toggle="dropdown" aria-expanded="false">
                        <img src="<?php echo e(asset('frontend/flags/' . currentLanguage()['flag'])); ?>" width="30" height="30" class="rounded-circle ms-2">
                        <?php echo e(currentLanguage()['name']); ?>

                    </button>
                    <ul class="dropdown-menu" aria-labelledby="userMenuDropdown">
                        <?php $__currentLoopData = $languages; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $lang): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <li>
                                <a class="dropdown-item" href="<?php echo e(route('change.language', $lang->code)); ?>">
                                    <img src="<?php echo e(asset('frontend/flags/' . $lang->app_lang_code . '.svg')); ?>" width="20" height="20" class="me-2">
                                    <?php echo e($lang->name); ?>

                                </a>
                            </li>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>
                </div>
            </div>
        </div>
    </div>
</header>

<!-- Drawer for Mobile View -->
<div id="drawer" class="drawer">
    <button id="close-drawer" class="close-drawer">✖</button>
    <ul class="drawer-menu">
        <?php $__currentLoopData = $menuItems; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $item): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <li class="<?php echo e(Request::is(trim($item->url, '/')) ? 'active' : ''); ?>">
                <a class="nav-link" href="<?php echo e($item->url); ?>">
                    <?php echo e($item->title); ?>

                </a>
            </li>
        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    </ul>
</div>
<?php /**PATH /home/filaoxuw/jusih.com/resources/views/frontend/partials/game-hive-header.blade.php ENDPATH**/ ?>