<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo e($page->title); ?> - HTML Games</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="<?php echo e(asset('frontend/css/style.css')); ?>">
    <style>
        .category-name {
            font-size: 16px;
            color: #d47217;
            top: 0;
        }

        .category-scroll-container {
            overflow-x: auto;
            white-space: nowrap;
            scrollbar-width: none;
        }

        .category-scroll-container::-webkit-scrollbar {
            display: none; /* Hide scrollbar for webkit browsers */
        }

        body {
            background-color: #121212;
            color: #f0f0f0;
        }

        .btn-primary {
            background-color: #ffcc00;
            border: none;
            color: #f0f0f0;
            font-weight: bold;
            text-transform: uppercase;
            letter-spacing: 1px;
        }

        .btn-primary:hover {
            background-color: #e6b800;
        }

        .ratio-16x9 iframe {
            border: 2px solid #ffcc00;
            border-radius: 5px;
        }

        .bg-light {
            background-color: #1e1e1e !important;
            color: #f0f0f0;
        }


    </style>
    <link href="https://fonts.googleapis.com/css2?family=Orbitron:wght@400;700&display=swap" rel="stylesheet">
</head>

<body>

    <!-- Header -->
    <?php echo $__env->make('frontend.partials._header', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    <!-- Game Area -->
    <div class="container-fluid my-4">
        <div class="row">
            <div class="col-md-12">
                <div class="category-scroll-container" id="categoryScrollContainer">
                    <div class="d-flex flex-nowrap">
                        <!-- Category 1 -->
                        <?php $__currentLoopData = $recentGames; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $recent): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <div class="text-center me-4">
                                <a style="text-decoration: none;color:#f0f0f0;" href="<?php echo e(route('game.play', $recent->slug)); ?>">
                                    <img src="<?php echo e(asset('images/games/icons/' . $recent->image)); ?>" class="card-img-top mx-auto" style="border-radius: 5px; width: 80px; height: 80px; object-fit: cover;">
                                    <p><?php echo e(Str::limit($recent->name, 15, '...')); ?></p>
                                </a>
                            </div>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </div>
                </div>
            </div>

            <div class="col-md-12">
                <div class="row">
                    <div class="col-lg-2 col-md-3 col-sm-12 mb-4 d-none d-lg-block">
                        <div class="row">
                            <?php $__currentLoopData = $mostplayedGames; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $mostplayed): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                <div class="col-md-6 text-center">
                                    <a class="text-white" style="text-decoration: none;" href="<?php echo e(route('game.play', $mostplayed->slug)); ?>">
                                        <img style="border-radius: 10px; width:100%;height:120px;" class="card-img-top mx-auto" src="<?php echo e(asset('images/games/icons/' . $mostplayed->image)); ?>" loading="lazy">
                                        <p><?php echo e($mostplayed->name); ?></p>
                                    </a>
                                </div>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        </div>
                    </div>

                    <div class="col-md-7">
                        <?php if($page->featured_image): ?>
                            <div class="ratio ratio-16x9">
                                <img src="<?php echo e(asset('images/pages/' . $page->featured_image)); ?>" frameborder="0" />
                            </div>
                        <?php endif; ?>
                        <div class="d-flex justify-content-between align-items-center mt-3">
                            <div>
                                <h3><?php echo e($page->title); ?></h3>
                            </div>

                        </div>
                        <p class="mt-4 text-light" style="color: white;"><?php echo $page->content; ?></p>

                    </div>
                    <div class="col-md-3">
                        <!-- Ad Space -->
                        <div class="bg-light p-4 mb-4">
                            <h5><?php echo e(translate('Advertisement')); ?></h5>
                            <img src="https://fakeimg.pl/400x400?text=Ad" class="img-fluid w-100" alt="Ad Placeholder">
                        </div>
                        <!-- Game Info Panel -->
                        <div class="bg-light p-4">
                            <h5><?php echo e(translate('Game Information')); ?></h5>
                            <ul>
                                <li>Mouse/Touchpad: Most HTML5 games use the mouse or touchpad for primary interactions. For example:</li>
                                    <ul>
                                        <li>Click: Click to select options, start the game, or perform actions like shooting or jumping.</li>
                                        <li>Drag and Drop: For games involving dragging elements, hold the left mouse button and move the mouse to drag objects.</li>
                                    </ul>
                                <li>Keyboard: Some games might require keyboard input. Common controls include:</li>
                                    <ul>
                                        <li>Arrow Keys (↑, ↓, ←, →): Move your character, navigate menus, or control in-game movement.</li>
                                        <li>Spacebar: Often used for actions like jumping, shooting, or pausing the game.</li>
                                        <li>Enter/Return: Start the game or confirm selections.</li>
                                        <li>Esc: Pause the game or access the game menu.</li>
                                    </ul>
                                <li>Game Objectives:</li>
                                    <ul>
                                        <li>Read the game’s objective, usually provided on the start screen or within a tutorial.</li>
                                        <li>Follow any in-game prompts or tutorials that guide you through the first few levels or actions.</li>
                                    </ul>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Footer -->
    <?php echo $__env->make('frontend.partials._footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            const scrollContainer = document.getElementById('categoryScrollContainer');

            let scrollAmount = 0;
            function autoScroll() {
                scrollAmount += 1; // Adjust this value for speed
                scrollContainer.scrollLeft = scrollAmount;

                if (scrollAmount >= scrollContainer.scrollWidth - scrollContainer.clientWidth) {
                    scrollAmount = 0; // Reset to start if reached the end
                }
            }

            setInterval(autoScroll, 50); // Adjust the interval for speed
        });
    </script>

</body>

</html>
<?php /**PATH /home/filaoxuw/jusih.com/resources/views/frontend/pages/index.blade.php ENDPATH**/ ?>